import SQLite from "react-native-sqlite-storage";
SQLite.DEBUG(true);
SQLite.enablePromise(true);
const database_name = "Reactoffline.db";
const database_version = "1.0";
const database_displayname = "SQLite React Offline Database";
const database_size = 200000;

export default class PendingSubtasks {
    //Create or Initialize the DB and PendingSubtasks Table or Open DataBase
    initDB() {
        let db;
        return new Promise((resolve) => {
            // console.warn("Plugin integrity check ...");
            SQLite.echoTest()
                .then(() => {
                    // console.warn("Integrity check passed ...");
                    console.log("Opening database ...");
                    SQLite.openDatabase(
                        database_name,
                        database_version,
                        database_displayname,
                        database_size
                    )
                        .then(DB => {
                            db = DB;
                            // console.warn("Database OPEN");
                            db.executeSql('SELECT 1 FROM pendingSubtasks LIMIT 1').then(() => {
                                // console.warn("Database is ready ... executing query ...");
                            }).catch((error) => {
                                // console.warn("Received error: ", error);
                                console.log("Database not yet ready ... populating data");
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS pendingSubtasks (subTaskId,taskTitle,mainTaskTitle,' +
                                        'mainTaskid,subTaskDesc,assignedBy,assignedDate,targetDate,taskEndDate,assignedTo,taskStatus,' +
                                        'status,dependencyId,dependencyTitle,dependencyUser,modifiedDate,taskStatusDesc,activeStatus,' +
                                        'timeLeft,today,count,cDate)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                            });
                            resolve(db);
                        })
                        .catch(error => {
                            console.warn(error);
                        });
                })
                .catch(error => {
                    console.warn("echoTest failed - plugin not functional");
                });
        });
    };

    //Close DataBase
    closeDatabase(db) {
        if (db) {
            console.log("Closing DB");
            db.close()
                .then(status => {
                    console.log("Database CLOSED");
                })
                .catch(error => {
                    this.errorCB(error);
                });
        } else {
            console.log("Database was not OPENED");
        }
    };

    //Add profile Data of User
    addPendingSubtasks(pending) {
        //   console.warn(profile.empid)
        let array = pending
        this.deletePendingSubtasksList();
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    // console.warn(profile.empStatus)
                    array.forEach(pending => {
                        // console.warn(pending.subTaskId)
                    tx.executeSql('INSERT INTO pendingSubtasks VALUES (?, ?, ?, ?, ? ,?, ?, ? ,?, ?, ?, ?, ?, ? ,?, ?, ? ,?, ?, ?, ? ,?)', [
                        pending.subTaskId, pending.taskTitle, pending.mainTaskTitle, pending.mainTaskid, pending.subTaskDesc, pending.assignedBy,
                        pending.assignedDate, pending.targetDate, pending.taskEndDate, pending.assignedTo, pending.taskStatus,
                        pending.status, pending.dependencyId, pending.dependencyTitle, pending.dependencyUser, pending.modifiedDate,
                        pending.taskStatusDesc, pending.activeStatus, pending.timeLeft, pending.today, pending.count, pending.cDate
                    ]).then(([tx, results]) => {
                        resolve(results);
                        // console.warn("success")
                    });
                });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Getting PendingSubtasksList Details 
    pendingSubtasksList() {
        console.warn("Query strated");
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM pendingSubtasks', []).then(([tx, results]) => {
                        console.warn("Query completed");
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { subTaskId, taskTitle, mainTaskTitle, mainTaskid, subTaskDesc, assignedBy, assignedDate, targetDate, taskEndDate,
                                assignedTo, taskStatus, status, dependencyId, dependencyTitle, dependencyUser, modifiedDate, taskStatusDesc,
                                activeStatus, timeLeft, today, count, cDate } = row;
                            profile.push({
                                subTaskId, taskTitle, mainTaskTitle, mainTaskid, subTaskDesc, assignedBy, assignedDate, targetDate, taskEndDate,
                                assignedTo, taskStatus, status, dependencyId, dependencyTitle, dependencyUser, modifiedDate, taskStatusDesc,
                                activeStatus, timeLeft, today, count, cDate
                            });
                        }
                        // console.warn(profile)
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Delete PendingSubtasksList 
        deletePendingSubtasksList() {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM pendingSubtasks', []).then(([tx, results]) => {
                        console.warn("deleted" + results);
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

}