/*
FileName:UserDashboardPersonalTodo.js
Version:1.0.0
Purpose:User todo list for personal todo list
Devloper:Mahesh Reddy
*/
import React, { Component } from 'react';
import { Platform, StyleSheet, Text, View, Dimensions, FlatList, TouchableHighlight, Picker, Image, TouchableOpacity, TextInput, Alert } from 'react-native';
import { Left, Button, Container, Header, Body, Title, Content, Item, Input, Right, } from 'native-base';
import AsyncStorage from '@react-native-community/async-storage';
import { widthPercentageToDP as wp, heightPercentageToDP as hp } from 'react-native-responsive-screen';
import Modal from "react-native-simple-modal";
import { Collapse, CollapseHeader, CollapseBody } from "accordion-collapse-react-native";
import Icon from 'react-native-vector-icons/FontAwesome';

// import Icon from 'react-native-vector-icons/FontAwesome';
import { API } from "../WebServices/RestClient";
import moment from "moment";
import NetInfo from '@react-native-community/netinfo';
import jwt_decode from "jwt-decode";
import Snackbar from 'react-native-snackbar';
import Toast from 'react-native-whc-toast';
// import DropDownPicker from 'react-native-dropdown-picker';
import ModalSelector from 'react-native-modal-selector';
// import { Dropdown } from 'react-native-material-dropdown';
import log from '../LogFile/Log';

import {
    BallIndicator,
    BarIndicator,
    DotIndicator,
    MaterialIndicator,
    PacmanIndicator,
    PulseIndicator,
    SkypeIndicator,
    UIActivityIndicator
} from 'react-native-indicators';

import { MODULES, TITLE, MODULEID, MODIFY, DELETE, MAINTASKTITLE } from '../CommonComponents/Header';
import UserDatabase from '../OfflineDB/UserDatabase';
import { ScrollView } from 'react-native-gesture-handler';
const db = new UserDatabase();

FOOTER_MAX_HEIGHT = 50
FOOTER_MIN_HEIGHT = 40

class ListItem extends React.Component {

    constructor(props) {
        super(props)

        this.state = {

            deletevisibility: false
        }
    }

    componentDidMount() {
        log("Debug", "Add Module screen is loaded");
        this.VisibleActions();
    }
    //Visable actions based on role start
    async VisibleActions() {

        AsyncStorage.getItem("emp_role", (err, res) => {

            //Alert.alert(res);

            if (res == 'Emp' || res == 'Manager' || res == 'Approver') {

                this.setState({ deletevisibility: true });
            } else {

                this.setState({ deletevisibility: false });
            }

        });

    }
    //Visable actions based on role close

    render() {
        const { item } = this.props;

        let button;

        if (this.state.deletevisibility === false) {
            button =
                <TouchableOpacity onPress={() => this.props.deleteAction()} style={{ margin: 2, backgroundColor: 'red', marginLeft: 5 }}>
                    <Text style={{ color: '#fff', textAlign: 'center' }}>{DELETE}</Text></TouchableOpacity>
        } else {
            button = null;
        }

        let button2;
        const { usertype } = this.props;
        if (item.assignbyId === usertype) {
            button2 =
                <View style={{ flexDirection: 'row', justifyContent: 'flex-end', alignItems: 'center' }}>
                    <TouchableOpacity style={{ margin: 2, backgroundColor: 'red', paddingRight: 10, justifyContent: 'center' }} onPress={this.props.deleteAction}>
                        <Text style={{ color: '#fff', textAlign: 'center', justifyContent: 'center', alignItems: 'center', marginLeft: 10 }}>{DELETE}</Text></TouchableOpacity>

                </View>

        } else {
            button2 = null;


        }
        let buttonMessage;
        if (item.personal_todo_status === '0') {
            buttonMessage = <View style={{ flexDirection: 'row', justifyContent: 'flex-end', marginTop: 5, marginBottom: 5 }}>

                <TouchableOpacity onPress={() => this.props.deleteAction()}>
                    <Image style={{ width: 27, height: 27, marginRight: 10 }} source={require('../Images/bin.png')} />
                </TouchableOpacity>
            </View>
        }
        else {
            buttonMessage =
                <View style={{ flexDirection: 'row', justifyContent: 'flex-end', marginTop: 5, marginBottom: 5 }}>

                    <TouchableOpacity onPress={() => this.props.deleteAction()}>
                        <Image style={{ width: 27, height: 27, marginRight: 10 }} source={require('../Images/bin.png')} />
                    </TouchableOpacity>
                    <TouchableOpacity onPress={() => this.props.completeAction()}>
                        <Image style={{ width: 27, height: 27, marginRight: 10 }} source={require('../Images/reassign.png')} />
                    </TouchableOpacity>
                    <TouchableOpacity onPress={() => this.props.ModifyModule()}>
                        <Image style={{ width: 25, height: 25, marginRight: 10 }} source={require('../Images/edit.png')} />
                    </TouchableOpacity>

                    <TouchableOpacity onPress={() => this.props.AssignTodo()}>
                        <Image style={{ width: 25, height: 25, marginRight: 10 }} source={require('../Images/agilemove.png')} />
                    </TouchableOpacity>
                </View>
        }
        return (

            <View style={item.complete_status === "pending" ? styles.container1 : styles.container}>

                <View style={(item.created_date > item.target_date && item.complete_status === 'pending' && item.target_date !== '0000-00-00') ? styles.statuspending : styles.statussuccess}>
                    <Collapse>
                        <CollapseHeader style={styles.box}>
                            <View style={{ flexDirection: 'row', paddingRight: 25, paddingBottom: 10 }}>
                                {/* <Text style={styles.signUpText4} >User Story Title :</Text>
                                <Text style={styles.signUpText3} >{item.story_title}</Text> */}

                                <View style={{ flexDirection: 'row', width: wp('86%') }}>
                                    {item.personal_todo_status == '1' ?
                                        <Text style={styles.signUpText00} >User Story Name1:</Text>
                                        : <Text style={styles.signUpText00m} >User Story Name:</Text>
                                    }
                                    {item.personal_todo_status === '1' ?
                                        <Text style={{ fontSize: 13, color: '#000000', width: '55%', paddingLeft: 10, }} >{item.story_title}</Text>
                                        : <Text style={{ fontSize: 13, color: '#000000', width: '55%', textDecorationLine: 'line-through', paddingLeft: 10, }} >{item.story_title}</Text>
                                    }

                                </View>
                            </View>
                            <View style={{ flexDirection: 'row', }}>
                                <View style={{ flexDirection: 'row', width: wp('76%') }}>
                                    <Text style={styles.signUpText4} >Description  :  </Text>
                                    <Text style={styles.signUpText3}>{item.story_desc}</Text>

                                </View>

                            </View>

                            <View style={{ flexDirection: 'row', justifyContent: 'flex-end', marginTop: 5, marginBottom: 5 }}>
                                {/* <TouchableOpacity onPress={() => this.props.deleteAction()}>
                                    <Image style={{ width: 27, height: 27, marginRight: 10 }} source={require('../Images/bin.png')} />
                                </TouchableOpacity>
                                <TouchableOpacity onPress={() => this.props.completeAction()}>
                                    <Image style={{ width: 27, height: 27, marginRight: 10 }} source={require('../Images/reassign.png')} />
                                </TouchableOpacity>
                                <TouchableOpacity onPress={() => this.props.ModifyModule()}>
                                    <Image style={{ width: 25, height: 25, marginRight: 10 }} source={require('../Images/edit.png')} />
                                </TouchableOpacity>

                                <TouchableOpacity onPress={() => this.props.AssignTodo()}>
                                    <Image style={{ width: 25, height: 25, marginRight: 10 }} source={require('../Images/agilemove.png')} />
                                </TouchableOpacity> */}
                                {buttonMessage}
                            </View>

                        </CollapseHeader>


                        <CollapseBody>



                            <View style={{ flexDirection: 'column', paddingRight: 25, paddingBottom: 10 }}>
                                <Text style={styles.signUpText4} >Acceptance Criteria :</Text>
                                <Text style={styles.signUpText3} >{item.acceptance_criteria}</Text>
                            </View>
                            <View style={{ flexDirection: 'column', paddingRight: 25, paddingBottom: 10 }}>
                                <Text style={styles.signUpText4} >Description :</Text>
                                <Text style={styles.signUpText3} >{item.story_desc}</Text>
                            </View>



                            <View style={{ flexDirection: 'row', paddingRight: 25, paddingBottom: 10 }}>
                                <Text style={styles.signUpText4} >Assigned By :</Text>
                                <Text style={styles.signUpText3} >{item.username}</Text>
                            </View>
                            <View style={{ flexDirection: 'row', paddingRight: 25, paddingBottom: 10 }}>
                                <Text style={styles.signUpText4} >Story Points :</Text>
                                <Text style={styles.signUpText3} >{item.story_points}</Text>
                            </View>
                            <View style={{ flexDirection: 'row', paddingRight: 25, paddingBottom: 10 }}>
                                <Text style={styles.signUpText4} >Priority Level :</Text>
                                <Text style={styles.signUpText3} >{item.priority_level}</Text>
                            </View>
                            {/* <View style={{ flexDirection: 'row', paddingRight: 25, paddingBottom: 10 }}>
                        <Text style={styles.signUpText4} >Assigned Date :</Text>
                        <Text style={styles.signUpText3} >{moment(item.assignedDate).format('MM/DD/YYYY hh:mm:ss')}</Text>
                    </View> */}


                        </CollapseBody>
                    </Collapse>
                </View>



            </View>

        )
    }
}

export default class UserDashboardPersonalTodo extends React.Component {

    constructor(props) {
        super(props);
        this.state = {
            open: false,
            modulename: '',
            role: '',
            userToken: '',
            isLoading: true,
            dataSource: [],
            empstatus: '',
            dataSource1: [],
            isFetching: false,
            modalVisible: false,
            //   idea_id: this.props.navigation.state.params.idea_id,
            //   idea_title: this.props.navigation.state.params.idea_title,
            action: '',
            moduleid: '',
            error1: '',
            itemPressedDisabled: false,
            squadName: '',
        };

        AsyncStorage.getItem("cropcode", (err, res) => {
            this.setState({ squadName: res });
            console.warn("squadname" + this.state.squadName);
        });

    }
    //open the Modal 
    modalDidOpen = () => console.log("Modal did open.");
    //close the Modal
    modalDidClose = () => {

        this.setState({ open: false }); this.setState({ open: false });
        console.log("Modal did close.");

    };

    //Dialog Actions start
    moveUp = () => this.setState({ offset: -100 });

    resetPosition = () => this.setState({ offset: 0 });

    openModal = () => this.setState({ open: true });

    //close dialog
    closeModal = () => {
        this.setState({
            open: false, error1: ''
        });
        this.setState({ modulename: '', priorityLevel: '', storyPoints: '', })
    }
    //Dialog Actions close

    componentDidMount() {
        log("Debug", " getModules screen is loaded");
        NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
                console.log(state.type);
                Snackbar.show({
                    title: 'No Internet Connection',
                    backgroundColor: 'red',
                    duration: Snackbar.LENGTH_LONG,
                });
                this.GetStatus();
                this.getArchiveList() //Offline Approved Projects List
            } else {
                this.getModules();
                this.GetStatus();
            }
        });
        AsyncStorage.getItem("userToken", (err, res) => {
            this.setState({ usertype: res });
            //alert(this.state.usertype);
        });

        // this.setModalVisible(!this.state.modalVisible);
    }

    //list of Modules getting
    add() {

        this.getModules();
    }

    //refresh data
    onRefresh() {
        this.setState({ isFetching: true }, function () { this.add() });
    }

    // componentWillReceiveProps(nextProps) {
    //   console.log(nextProps);
    //   console.log("re loading...........")
    //   this.getModules();
    // }
    componentWillReceiveProps(nextProps) {
        NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
                console.log(state.type);
                Snackbar.show({
                    title: 'No Internet Connection',
                    backgroundColor: 'red',
                    duration: Snackbar.LENGTH_LONG,
                });
                this.getModules(); //For pending subtaskslist from offline
            } else {
                this.getModules();
            }
        });

    }
    //For store Agile projects for offline Start
    addAgileProjects(data) {
        console.warn("hello naveen" + JSON.stringify(data));
        db.addAgileProjects(data).then((result) => {
            console.log(result);
        }).catch((err) => {
            console.log(err);
        })
    }
    //For store Agile projects for offline End
    //For Getting offline Project List Start
    getAgileProjects() {
        db.getAgileProjects().then((data) => {
            console.warn("AgileProjectsList" + JSON.stringify(data))
            this.setState({
                data2: data,
            });
        }).catch((err) => {
        })
    }
    //For Getting offline Project List End

    //For Archives List from offline
    getArchiveList() {
        AsyncStorage.getItem("cropcode", (err, res) => {
            const projectName = res;
            db.getArchiveList(projectName).then((data) => {
                console.warn("Approved ProjectList" + JSON.stringify(data))
                this.setState({
                    dataSource: data,
                    isLoading: false,
                });
                this.arrayholder = data;
            }).catch((err) => {
                console.log(err);
                this.setState = {
                    isLoading: false
                }
            })
        });
    }

    //For store Archives list from offline
    addArchivesList(data, cropcode) {
        console.warn("addarchives" + JSON.stringify(data))
        db.addArchivesList(data, cropcode).then((result) => {
            this.setState({
                isLoading: false,
            });
        }).catch((err) => {

            this.setState({
                isLoading: false,
            });
        })
    }


    //get project list dropdown data
    GetStatus() {
        log("Info", "UserProfile:GetStatus() method is used to get status of employee");
        AsyncStorage.getItem("userToken", (err, res) => {
            const empId = res;
            NetInfo.fetch().then(state => {
                if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
                    // console.log(state.type);
                    Snackbar.show({
                        title: 'No Internet Connection',
                        backgroundColor: 'red',
                        duration: Snackbar.LENGTH_LONG,
                    });
                    this.getAgileProjects(); //Get offline Project List
                } else {

                    fetch(API + 'squads.php', {
                        method: 'POST',
                        headers: {
                            Accept: 'application/json',
                            'Content-Type': 'application/json',
                        },
                        body: JSON.stringify({

                            empId: empId,
                            action: 'get_squads',


                        })
                    })
                        .then((response) => response.json())
                        .then((responseJson) => {
                            console.warn(responseJson)
                            //alert(JSON.stringify(responseJson))

                            if (responseJson.status == 'True') {
                                // this.setState({
                                //     isLoading: false,
                                //     dataSource1: [...responseJson.data],
                                // }, function () {
                                //     // In this block you can do something with new state.
                                // });
                                console.log("Testing" + JSON.stringify(responseJson.data))
                                const data2 = [];
                                this.addAgileProjects(responseJson.data) //Project list store in offline

                                responseJson.data.map(x => {
                                    data2.push({ label: x.value, value: x.value })
                                })
                                this.setState({
                                    data2: data2,
                                })
                                console.warn("Hello" + JSON.stringify(data2))

                                // this.setState({
                                //     data2: responseJson.data
                                // });
                                console.warn(this.state.data2);
                            } else {
                                log("Warn", "status of employee is not available");
                            }
                        })
                        .catch((error) => {
                            console.error(error);
                            log("Error", "error in  getting status of employee");
                        });
                }
            });
        });

    }

    // Update Status of Employee
    UpdateStatus(squadName) {
        // const { squadName } = this.state;
        log("Info", "UserProfile:UpdateStatus(status) method is used to update status of employee");
        console.warn("project" + JSON.stringify(squadName));

        AsyncStorage.getItem("userToken", (err, res) => {
            const empId = res;
            console.log(res);

            AsyncStorage.getItem("projectId", (err, res) => {
                const projectId = res;



                // console.log(cropcode);
                NetInfo.fetch().then(state => {
                    if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
                        console.log(state.type);
                        Snackbar.show({
                            title: 'No Internet Connection',
                            backgroundColor: 'red',
                            duration: Snackbar.LENGTH_LONG,
                        });
                        //for offline project switching start
                        this.setState({
                            squadName: squadName
                        });
                        AsyncStorage.setItem('cropcode', squadName);
                        this.getArchiveList()
                        //for offline project switching end
                    } else {

                        fetch(API + 'squad_login.php', {
                            method: 'POST',
                            headers: {
                                Accept: 'application/json',
                                'Content-Type': 'application/json',
                            },
                            body: JSON.stringify({
                                username: empId,
                                corp: squadName,
                                projectId: projectId
                            })
                        })
                            .then((response) => response.json())
                            .then((responseJson) => {
                                console.warn(JSON.stringify(responseJson))
                                // alert(JSON.stringify(responseJson))

                                if (responseJson.status == 'TRUE') {
                                    AsyncStorage.setItem('auth', responseJson.jwt) //store the token information  with exp
                                    const tokenDetails = jwt_decode(responseJson.jwt);
                                    console.log(tokenDetails.data)
                                    AsyncStorage.setItem('roleCount', tokenDetails.data.roleCount)
                                    // dispatch(setCurrentUser(tokenDetails.data)); //store the user information
                                    AsyncStorage.setItem('status', tokenDetails.data.empStatus)


                                    AsyncStorage.setItem('userToken', tokenDetails.data.empId);
                                    AsyncStorage.setItem('userName', tokenDetails.data.userName);
                                    AsyncStorage.setItem('emp_role', tokenDetails.data.role);
                                    AsyncStorage.setItem('cropcode', tokenDetails.data.corp);
                                    AsyncStorage.setItem('projectId', tokenDetails.data.projectId);
                                    // this.props.navigation.navigate('UserProfile');
                                    // console.warn("HI" + empstatus)
                                    this.setState({

                                        squadName: tokenDetails.data.corp,

                                    });
                                    //  alert("Project Changed Successfully")
                                    this.getModules();

                                } else {
                                    //    alert("user already exist");
                                    log("Warn", "status of employee is not able to update");
                                }

                            })
                            .catch((error) => {
                                console.warn(error);
                                log("Error", "error in updating status of employee");
                            });
                    }
                });
            });
        });

    }



    // delete task start
    deleteAction(item, index) {
        log("Info", "UserDashboardPersonalTodo:deleteAction(pt_id) method is used to give alert");
        Alert.alert(
            'Alert..!',
            'Do you want to delete task',
            [
                {
                    text: 'Cancel',
                    onPress: () => console.log('Cancel Pressed'),
                    style: 'cancel',
                },
                { text: 'OK', onPress: () => this.deleteTask(item, index) },
            ],
            { cancelable: false },
        );
    }

    //delete the Task
    deleteTask(item, index) {
        log("Info", "deleteProject() method is used to delete project");
        AsyncStorage.multiGet(["cropcode", "userToken", "emp_role"], (err, response) => {
            const cropcode = response[0][1];
            const userToken = response[1][1];
            console.warn("userToken" + userToken)
            const role = response[2][1];
            AsyncStorage.getItem("projectId", (err, res) => {
                const projectId = res;
                NetInfo.fetch().then(state => {
                    if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
                        console.log(state.type);
                        Snackbar.show({
                            title: 'No Internet Connection',
                            backgroundColor: 'red',
                            duration: Snackbar.LENGTH_LONG,
                        });
                    } else {
                        fetch(API + 'private_todo.php', {
                            method: 'POST',
                            headers: {
                                'Accept': 'application/json',
                                'Content-Type': 'application/json',
                            },
                            body: JSON.stringify({
                                pt_id: item.pt_id,
                                action: 'delete',


                            })
                        }).then((response) => response.json())
                            .then((responseJson) => {
                                console.log(JSON.stringify(responseJson));
                                console.log(responseJson);
                                // alert(JSON.stringify(responseJson));
                                if (responseJson.status === 'True') {
                                    // this.refs.toast.showCenter('Epic Squad is Deactivated', Toast.Duration.long, Toast.Position.center);
                                    console.log("done")
                                    // alert(JSON.stringify(responseJson.message));
                                    alert("Sucessfully Deleted")
                                    //this.refs.toast.showBottom('Employee is Deleted');
                                    this.getModules();
                                    this.setState({ open: false })
                                    // this.props.navigation.navigate('Aproved');
                                    // this.UserManageEmployees();
                                }
                                else {
                                    alert(responseJson.message);
                                    // this.refs.toast.showCenter('Epic Squad is not Deactivated', Toast.Duration.long, Toast.Position.center);
                                }
                            }).catch((error) => {
                                console.error(error);
                                //alert("Hello");
                                log("Error", "error in employee deletion");
                            });
                    }
                });
            });
        });
    };
    //Delete task end


    // delete task start
    completeAction(item, index) {
        log("Info", "UserDashboardPersonalTodo:compeleteTask(pt_id) method is used to give alert");
        Alert.alert(
            'Alert..!',
            'Do you want to complete task',
            [
                {
                    text: 'Cancel',
                    onPress: () => console.log('Cancel Pressed'),
                    style: 'cancel',
                },
                { text: 'Complete', onPress: () => this.compeleteTask(item, index) },
            ],
            { cancelable: false },
        );
    }

    //Complete the Task
    compeleteTask(item, index) {
        log("Info", "deleteProject() method is used to delete project");
        AsyncStorage.multiGet(["cropcode", "userToken", "emp_role"], (err, response) => {
            const cropcode = response[0][1];
            const userToken = response[1][1];
            console.warn("userToken" + userToken)
            const role = response[2][1];
            AsyncStorage.getItem("projectId", (err, res) => {
                const projectId = res;
                NetInfo.fetch().then(state => {
                    if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
                        console.log(state.type);
                        Snackbar.show({
                            title: 'No Internet Connection',
                            backgroundColor: 'red',
                            duration: Snackbar.LENGTH_LONG,
                        });
                    } else {
                        fetch(API + 'private_todo.php', {
                            method: 'POST',
                            headers: {
                                'Accept': 'application/json',
                                'Content-Type': 'application/json',
                            },
                            body: JSON.stringify({
                                pt_id: item.pt_id,
                                action: 'complete',
                                // crop :cropcode,
                                // added_by:userToken




                            })
                        }).then((response) => response.json())
                            .then((responseJson) => {
                                console.log(JSON.stringify(responseJson));
                                console.log(responseJson);
                                // alert(JSON.stringify(responseJson));
                                if (responseJson.status === 'True') {
                                    // this.refs.toast.showCenter('Epic Squad is Deactivated', Toast.Duration.long, Toast.Position.center);
                                    console.log("done")
                                    alert(JSON.stringify(responseJson.message));
                                    //this.refs.toast.showBottom('Employee is Deleted');
                                    this.getModules();
                                    this.setState({ open: false })
                                    // this.props.navigation.navigate('Aproved');
                                    // this.UserManageEmployees();
                                }
                                else {
                                    alert(responseJson.message);
                                    // this.refs.toast.showCenter('Epic Squad is not Deactivated', Toast.Duration.long, Toast.Position.center);
                                }
                            }).catch((error) => {
                                console.error(error);
                                //alert("Hello");
                                log("Error", "error in employee deletion");
                            });
                    }
                });
            });
        });
    };
    //Complete task end


    //get Module list start
    getModules() {

        const { idea_id } = this.state;

        console.log(idea_id);

        AsyncStorage.getItem("cropcode", (err, res) => {

            const cropcode = res;
            AsyncStorage.getItem("emp_role", (err, res) => {
                const role = res;
                AsyncStorage.getItem("projectId", (err, res) => {
                    const projectId = res;

                    AsyncStorage.getItem("userToken", (err, res) => {
                        const empId = res;
                        // alert(empId)
                        NetInfo.fetch().then(state => {
                            if (state.type == "none") {
                                console.log(state.type);
                                log("Warn", "No internet connection");
                                Snackbar.show({
                                    title: 'No Internet Connection',
                                    backgroundColor: 'red',
                                    duration: Snackbar.LENGTH_LONG,
                                });
                            } else {
                                fetch(API + 'private_todo.php', {
                                    method: 'POST',
                                    headers: {
                                        Accept: 'application/json',
                                        'Content-Type': 'application/json',
                                    },
                                    body: JSON.stringify({
                                        action: 'private_todo',
                                        added_by: empId,
                                        crop: cropcode,
                                    })
                                })
                                    .then((response) => response.json())
                                    .then((responseJson) => {
                                        // alert(JSON.stringify(responseJson));
                                        console.warn(JSON.stringify(responseJson))

                                        if (responseJson.status === 'True') {
                                            // this.addArchivesList(responseJson.data, cropcode) //Store Approved Projects List Offline
                                            this.setState({
                                                isLoading: false,
                                                dataSource: responseJson.data,
                                                isFetching: false
                                            }, function () {

                                            });
                                            this.arrayholder = responseJson.data;
                                        }

                                        else {
                                            this.arrayholder = [];
                                            this.setState({
                                                isLoading: false,
                                                dataSource: [],
                                            })
                                            Snackbar.show({
                                                title: 'No Private Todo List',
                                                backgroundColor: '#3BB9FF',
                                                duration: Snackbar.LENGTH_LONG,
                                            });
                                        }
                                    })

                                    .catch((error) => {
                                        this.setState({
                                            isLoading: false,
                                        })
                                        console.error(error);
                                        log("Error", "Add Module error");
                                    });
                            }
                        });
                    });
                });
            });
        });
    }
    //get Module list end


    //Checking the Validations
    isValidData() {
        const { tasktitle, taskdescription, acceptanceCriteria, } = this.state;
        let valid = false;
        console.warn(this.state.assignedto);
        if (tasktitle.length === 0) {
            log("Warn", "tasktitle title should not be empty");
            this.setState({ error1: 'Enter Title ' });
        }
        else if (taskdescription.length === 0) {
            // alert("Enter Description");
            log("Warn", "taskdescription title should not be empty");
            this.setState({ error2: 'Enter Description ' });
        }
        else if (acceptanceCriteria.length === 0) {
            log("Warn", "acceptanceCriteria should not be empty");
            this.setState({ error4: 'Enter Acceptance Criteria' });
        }


        else {
            valid = true;
        }
        return valid;
    }


    //to add the new project from user 
    addMainTask = () => {
        log("Info", "addProject() method is used to add new project at user side");
        NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == "unknown" || state.type == 'undefined') {
                console.log(state.type);
                Snackbar.show({
                    title: 'No Internet Connection',
                    backgroundColor: 'red',
                    duration: Snackbar.LENGTH_LONG,
                });
            }
            else {
                const { tasktitle, taskdescription, acceptanceCriteria, storyPoints, priorityLevel, epicId } = this.state;

                console.warn("tasktitle" + tasktitle);
                console.warn("taskdescription" + taskdescription);

                console.warn("acceptanceCriteria" + acceptanceCriteria);
                // console.warn("epicId" + epicId);
                console.warn("storyPoints" + storyPoints);
                console.warn("priorityLevel" + priorityLevel);

                if (this.isValidData()) {
                    this.setState({ itemPressedDisabled: true })
                    AsyncStorage.multiGet(["cropcode", "userToken", "emp_role"], (err, response) => {
                        const cropcode = response[0][1];
                        const userToken = response[1][1];
                        AsyncStorage.getItem("projectId", (err, res) => {
                            const projectId = res;
                            console.warn("userToken" + userToken)
                            const role = response[2][1];
                            AsyncStorage.getItem("userId", (err, res) => {
                                const userId = res;
                                fetch(API + 'private_todo.php', {
                                    method: 'POST',
                                    headers: {
                                        'Accept': 'application/json',
                                        'Content-Type': 'application/json',
                                    },
                                    body: JSON.stringify({
                                        // proj_title: this.state.ProjectTitle,
                                        // proj_desc: this.state.ProjectDescription,
                                        // empId:userToken, //Async
                                        // action: "add",
                                        // crop: cropcode //Async

                                        action: "personal_todo_add",
                                        crop: cropcode,
                                        title: this.state.tasktitle,
                                        description: this.state.taskdescription,
                                        // module_id: ModuleId,
                                        // module_id: '',
                                        // idea_id: epicId,
                                        added_to: this.state.assignedto,
                                        acceptanceCriteria: acceptanceCriteria,
                                        storyPoints: storyPoints,
                                        added_by: userToken,
                                        priorityLevel: this.state.priorityLevel,
                                        // sprintDesc: this.state.sprintDesc,
                                        // epicId: this.state.epicId,
                                        // projectId: projectId,
                                        // device_id: userId,
                                    })
                                }).then((response) => response.json())
                                    .then((responseJson) => {
                                        console.warn("Data Testing" + JSON.stringify(responseJson));
                                        console.log(responseJson);


                                        if (responseJson.status === 'True') {
                                            this.setState({ open: false });
                                            this.refs.toast.showCenter('Task Added Successfully');
                                            // this.props.navigation.goBack();
                                            // console.log(responseJson);
                                            // alert("Task Added Successfully");
                                            this.setState({
                                                itemPressedDisabled: false,
                                                priorityLevel: '',
                                                storyPoints: '',
                                            })
                                            console.log("done")

                                            this.getModules();

                                        }
                                    }).catch((error) => {
                                        console.error(error);
                                        log("Error", "error in User Story adding");
                                    });
                            });
                        });
                    });
                    // this.closeModal();
                }
            }

        });

    };



    //Validatios
    isValid() {
        const { modulename } = this.state;
        let valid = false;

        if (modulename.length === 0) {
            log("Warn", "module name should not be empty");
            // ToastAndroid.showWithGravity('"Enter sub Task', ToastAndroid.SHORT,ToastAndroid.CENTER);
            this.setState({ error1: 'Module Title ' });
        }

        else {
            valid = true;
        }
        return valid;
    }
    //Add the new Module


    //Navigate to maintask screen
    MainTask(item, index) {

        console.log(item);
        console.log(index);

        console.log(item.ideaId + item.moduleId);
        log("Info", "MainTask() method is used to move Add Module to Add MainTask screen");
        this.props.navigation.navigate('AddMainTask1', { moduleId: item.sprint_id, empId: item.empId, idea_title: item.ideaTitle, ideaid: item.epic_id, moduledesc: item.moduleDesc, });

        // this.props.navigation.navigate('AddMainTask', { moduleId: item.moduleId,empId:item.empId,idea_title:item.ideaTitle, ideaid: item.ideaId,moduledesc:item.moduleDesc,idea_title:this.state.idea_title});

    }

    //Navigate to Module Modify Screen
    ModifyModule(item, index) {
        console.log(item);
        console.log(index);
        log("Info", "ModifyModule() method is used to move Add Module to Add ModuleAdd screen");
        this.props.navigation.navigate('ModifyPersonalTodo', { action: 'modify', pt_id: item.pt_id, story_title: item.story_title, story_desc: item.story_desc, priorityLevel: item.priority_level, storyPoints: item.story_points, acceptanceCriteria: item.acceptance_criteria });

    }

    //Navigate to Assign screen
    AssignTodo(item, index) {
        console.log(item);
        console.log(index);
        log("Info", "AssignTodo() method is used to move Add Module to Add ModuleAdd screen");
        this.props.navigation.navigate('AssignTodo', { pt_id: item.pt_id, story_title: item.story_title, story_desc: item.story_desc, priorityLevel: item.priority_level, storyPoints: item.story_points, acceptanceCriteria: item.acceptance_criteria });

    }

    //Seperate the list of data
    FlatListItemSeparator = () => {
        return (
            <View
                style={{
                    //  height: .5,
                    width: "100%",
                    backgroundColor: "#000",
                }}
            />
        );
    }


    //For empty data(No list available)
    _listEmptyComponent = () => {
        return (
            <View style={{ width: '90%', height: '80%' }}>
                <Text></Text>
            </View>
        )
    }


    //to filter the search in put by user 
    SearchFilterFunction(text) {
        log("Info", "UserApprovedProjects:SearchFilterFunction(text) method is used for search functionality");
        console.log(text);
        const newData = this.arrayholder.filter(function (item) {
            const story_desc = item.story_desc.toUpperCase()
            const story_desc1 = text.toUpperCase()
            // const date = item.date.toUpperCase()
            // const date1 = text.toUpperCase()
            const story_title = item.story_title.toUpperCase()
            const story_title1 = text.toUpperCase()
            // const notification_from = item.notification_from.toUpperCase()
            // const notification_from1 = text.toUpperCase()



            return story_desc.indexOf(story_desc1) > -1 ||
                // date.indexOf(date1) > -1 ||
                story_title.indexOf(story_title1) > -1
            // notification_from.indexOf(notification_from1) > -1


        })
        this.setState({
            dataSource: newData,
            text: text
        })
    }

    render() {
        if (this.state.isLoading) {
            return (
                <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                    <DotIndicator color='#00A2C1' />
                </View>
            );

        }

        let index = 0;
        const data = [
            { key: index++, label: '1' },
            { key: index++, label: '2' },
            { key: index++, label: '3' },
            { key: index++, label: '5' },
            { key: index++, label: '8' },
            { key: index++, label: '13', },

        ];

        const data1 = [
            { key: index++, label: '1' },
            { key: index++, label: '2' },
            { key: index++, label: '3' },
            { key: index++, label: '4' },
            { key: index++, label: '5' },


        ];
        return (
            <Container style={{ height: Dimensions.get('window').height }}>
                {/* <NavigationEvents
          onDidFocus={() => this.onRefresh()}
        /> */}

                {/* <Header
                    androidStatusBarColor="#00A2C1"
                    style={{
                        backgroundColor: '#00A2C1',
                        height: 60,
                        width: Dimensions.get('window').width,
                        borderBottomColor: '#ffffff',
                        justifyContent: 'space-between',
                    }}> */}
                {/* <View style={{ marginTop: 20 }}>
                        <Icon name="md-menu" size={25} style={{ color: 'white', }} onPress={() =>
                            this.props.navigation.toggleDrawer()} />
                    </View> */}


                {/* <View style={{ flexDirection: 'row', marginLeft: 15 }}> */}
                {/* <View style={{backgroundColor:'white',width:300,borderRadius:20,height:50,marginTop:5}}> */}
                {/* <View style={{ width: 300, borderRadius: 20, height: 45, marginTop: 5, flexDirection: 'row' }}> */}

                {/* <ModalSelector
                            style={{ width: 260, backgroundColor: 'transparent', borderColor: 'transparent', marginLeft: 60 }}
                            data={this.state.data2}
                            optionContainerStyle={{ backgroundColor: 'white' }}
                            initValue={this.state.squadName}
                            onChange={(itemValue) => { this.UpdateStatus(itemValue.label) }} >
                            <View style={{ width: 300, borderRadius: 20, backgroundColor: '#00A2C1', height: 45, flexDirection: 'row' }}>
                                <Text style={{ marginTop: 15, color: 'white', width: 80 }}>PROJECT : </Text>

                                <Text style={{ marginTop: 15, color: 'white', width: 120, }}>{this.state.squadName}</Text>

                                <Icon name="md-chevron-down-outline" size={25} style={{ color: 'white', marginTop: 10, }}
                                />
                            </View>

                        </ModalSelector> */}
                {/* <Text style={{ marginTop: 15, color: 'white', marginLeft: 20, fontSize: 16 }}>Todo</Text>
                    </View> */}

                {/* </Header> */}
                <Item>
                    <Input placeholder="Search"
                        onChangeText={(text) => this.SearchFilterFunction(text)} />
                    <Icon size={20} name="search" />
                </Item>
                <View style={styles.MainContainer}>
                    <Toast ref="toast" />
                    <View style={{ height: '88%' }}>

                        <FlatList

                            extraData={this.state}
                            keyExtractor={this._keyExtractor}
                            renderItem={this._renderItem}

                            data={this.state.dataSource}

                            onRefresh={() => this.onRefresh()}
                            refreshing={this.state.isFetching}

                            ItemSeparatorComponent={this.FlatListItemSeparator}
                            renderItem={({ item, index }) =>
                                <View>

                                    <ListItem navigation={this.props.navigation}
                                        item={item}
                                        usertype={this.state.usertype}
                                        MainTask={() => this.MainTask(item, index)}//For Add Maintask
                                        AssignTodo={() => this.AssignTodo(item, index)}//Assign Todo
                                        // openModal={() => this.openModal(item, index)}//For Add Module
                                        ModifyModule={() => this.ModifyModule(item, index)}//For Modify Module
                                        deleteAction={() => this.deleteAction(item, index)}//For delete module
                                        completeAction={() => this.completeAction(item, index)}//For complete module

                                    />
                                </View>
                            }
                            keyExtractor={item => item.id}
                            ListEmptyComponent={this._listEmptyComponent}
                        />

                    </View>
                    <View style={styles.bottomView} >
                        <TouchableOpacity onPress={this.openModal} >
                            {/* <Icon name='lightbulb-o'color='white' type='MaterialCommunityIcons' size={30} /> */}
                            <Text style={styles.textStyle}>Add Task</Text>
                        </TouchableOpacity>
                    </View>

                    <Modal
                        offset={this.state.offset}
                        open={this.state.open}
                        modalDidOpen={this.modalDidOpen}
                        modalDidClose={this.modalDidClose}
                        closeOnTouchOutside={false}
                        style={{ alignItems: "center" }} >

                        {/* <Text style={{ justifyContent: 'center', fontSize: 16 }}>Add Task</Text> */}

                        <ScrollView style={{ paddingBottom: 40 }}>


                            <View style={{ paddingLeft: 10, width: '100%', }}>

                                <TextInput style={{ width: '98%', height: 45, color: 'black', borderBottomWidth: 1, }}
                                    placeholder={MAINTASKTITLE}
                                    underlineColorAndroid='transparent'
                                    // selectionColor='white'
                                    onChangeText={(maintask) => this.setState({ tasktitle: maintask })}
                                >
                                </TextInput>

                                <Text style={{ color: 'red' }}>{this.state.error1}</Text>
                            </View>

                            <View style={{ paddingLeft: 10, width: '100%' }}>


                                <TextInput style={{ width: '98%', height: 45, color: 'black', borderBottomWidth: 1, }}
                                    placeholder='Description:'
                                    underlineColorAndroid='transparent'
                                    // selectionColor='white'
                                    onChangeText={(description) => this.setState({ taskdescription: description })}>
                                </TextInput>
                                <Text style={{ color: 'red' }}>{this.state.error2}</Text>
                            </View>
                            <View style={{ paddingLeft: 10, width: '100%' }}>


                                <TextInput style={{ width: '98%', height: 45, color: 'black', borderBottomWidth: 1, }}
                                    placeholder="Acceptance Criteria/Definition of Done"
                                    underlineColorAndroid='transparent'
                                    // selectionColor='white'
                                    onChangeText={(acceptanceCriteria) => this.setState({ acceptanceCriteria: acceptanceCriteria })}>
                                </TextInput>
                                <Text style={{ color: 'red' }}>{this.state.error4}</Text>
                            </View>


                            <Text style={{ marginLeft: 10, paddingTop: 10, paddingBottom: 5 }}>Story Points</Text>

                            <View style={{ width: '98%' }}>
                                <ModalSelector
                                    data={data}
                                    initValue="Select something yummy!"
                                    // supportedOrientations={['landscape']}
                                    accessible={true}
                                    optionContainerStyle={{ backgroundColor: 'white' }}
                                    scrollViewAccessibilityLabel={'Scrollable options'}
                                    cancelButtonAccessibilityLabel={'Cancel Button'}
                                    onChange={(option) => { this.setState({ storyPoints: option.label }) }}>

                                    <TextInput
                                        style={{ borderWidth: 1, borderColor: '#ccc', padding: 10, height: 50, width: '98%', marginLeft: '1%', color: 'black' }}
                                        editable={false}
                                        placeholder="Select Story Points!"
                                        value={this.state.storyPoints} />

                                </ModalSelector>
                            </View>

                            <Text style={{ marginLeft: 10, paddingTop: 10, paddingBottom: 5 }}>Priority Level</Text>

                            <View style={{ width: '98%' }}>

                                <ModalSelector
                                    data={data1}
                                    initValue="Select Priority  Points!"
                                    // supportedOrientations={['landscape']}
                                    accessible={true}
                                    optionContainerStyle={{ backgroundColor: 'white' }}
                                    scrollViewAccessibilityLabel={'Scrollable options'}
                                    cancelButtonAccessibilityLabel={'Cancel Button'}
                                    onChange={(option) => { this.setState({ priorityLevel: option.label }) }}>

                                    <TextInput
                                        style={{ borderWidth: 1, borderColor: '#ccc', padding: 10, height: 50, width: '98%', marginLeft: '1%', color: 'black' }}
                                        editable={false}
                                        placeholder="Select Priority  Points!"
                                        value={this.state.priorityLevel} />

                                </ModalSelector>
                            </View>

                            <View style={{ flexDirection: 'row', marginTop: 10, justifyContent: "space-between" }}>
                                <TouchableOpacity style={styles.opensave} onPress={this.addMainTask.bind(this)} disabled={this.state.itemPressedDisabled}>
                                    <Text style={{ color: 'white' }}>Add</Text>
                                </TouchableOpacity>
                                <TouchableOpacity style={styles.opencancel} onPress={this.closeModal} >
                                    <Text style={{ color: 'white' }}>CANCEL</Text>
                                </TouchableOpacity>
                            </View>
                        </ScrollView>


                    </Modal>


                </View>

            </Container>


        );

    }

}
//Styles for UI
const styles = StyleSheet.create(
    {
        MainContainer:
        {
            flex: 1,
            width: Dimensions.get('window').width,
            height: Dimensions.get('window').height,
            backgroundColor: '#f8f8f8'
        },
        bottomView: {
            flexDirection: 'row',
            justifyContent: 'center',
            position: 'absolute',
            height: FOOTER_MAX_HEIGHT,
            bottom: 0,
            left: 0,
            right: 0,
            backgroundColor: 'black',
            alignItems: 'center'
        },

        textStyle: {
            color: '#fff',
            fontSize: 18,
            // backgroundColor:'#00a2c1',
            paddingLeft: 10,
            paddingRight: 10,
            paddingBottom: 5,
            paddingTop: 5,
            borderRadius: 5,

        },
        container: {
            flex: 1,
            width: '100%',
            backgroundColor: '#fff'

        },
        container1: {
            flex: 1,
            width: '100%',
            backgroundColor: '#BEF29F',

        },
        footer: {
            position: 'absolute',
            flex: 0.1,
            left: 0,
            right: 0,
            bottom: -10,
            backgroundColor: 'green',
            flexDirection: 'row',
            height: 80,
            alignItems: 'center',
        },
        bottomButtons: {
            alignItems: 'center',
            justifyContent: 'center',
            flex: 1,
        },
        footerText: {
            color: 'white',
            fontWeight: 'bold',
            alignItems: 'center',
            fontSize: 18,
        },
        buttonContainer: {
            width: wp('90%'),
            alignSelf: 'baseline',
            marginBottom: 25,
            color: '#d2691e',
            marginLeft: 4,
            backgroundColor: '#f8f8f8',



        },
        signupButton: {

            backgroundColor: '#f8f8f8',
        },
        subcontainer: {
            flex: 2,
            flexDirection: 'row',
            paddingTop: 40
        },
        signUpText0: {
            fontSize: 13,
            color: '#00A2C1',
            paddingTop: 10,
            paddingLeft: 5,
            fontWeight: "bold",

        },
        signUpText1: {
            fontSize: 13,
            color: '#00A2C1',
            paddingTop: 10,
            fontWeight: "bold",
            // width: '70%'
        },
        end: {

            alignItems: 'flex-end',

        },
        end1: {
            flex: 2,
            height: '50%',
            paddingTop: 20,
            justifyContent: 'space-between',

            flexDirection: 'row',
        },
        s: {
            justifyContent: 'center',

            backgroundColor: '#ed7070',
            shadowOffset: { width: 50, height: 50 },
            alignItems: 'center',
            width: wp('40%'),
            height: hp('12%'),

        },
        prioritylevel: {
            fontSize: 10,
            fontSize: 13,
            color: 'black',
            padding: 10,
            backgroundColor: '#008080',
            color: 'white',
            marginTop: 5,

        },

        statuspending: {
            borderRadius: 5, margin: 6, borderColor: 'grey', borderWidth: 0.5, marginTop: 10, backgroundColor: '#ffa07a'
        },
        statussuccess: {
            borderRadius: 5, margin: 6, borderColor: 'grey', borderWidth: 0.5, marginTop: 10, backgroundColor: 'white'
        },
        activelevel: {
            fontSize: 10,
            fontSize: 13,
            color: 'black',
            padding: 10,
            backgroundColor: '#728fce',
            marginLeft: 10,
            borderRadius: 30,
            color: 'white',
            marginTop: 5,

        },
        signUpText3: {

            fontSize: 12,
            // paddingTop: 10,
            paddingLeft: 10,
            width: '75%',
            alignItems: 'center',
        },
        signUpText4: {
            fontSize: 12,
            // paddingTop: 10,
            paddingLeft: 5,
            // backgroundColor:'#f8f8f8',


            alignItems: 'center',
        },
        signup: {

            color: "#FFF",

        },
        boxone: {
            flex: 1,


        },
        boxtwo: {
            flex: 1,

        },
        boxthree: {
            flex: 1,

        },
        box: {
            // flexDirection: 'row',
            borderRadius: 2,
            margin: 2

        },
        signUpText: {
            fontSize: 20,
            justifyContent: 'center',

            color: 'white',
            alignSelf: 'center',

        },

        opencancel: {
            flex: 1,
            ...Platform.select({
                ios: {
                    backgroundColor: 'red', margin: 20, height: 30, alignItems:
                        "center", justifyContent: 'center'
                },
                android: {
                    backgroundColor: 'red', margin: 20, height: 30, alignItems:
                        "center", justifyContent: 'center'
                },
            }),
        },
        opensave: {
            flex: 1,
            ...Platform.select({
                ios: {
                    backgroundColor: 'green', margin: 20, height: 30, alignItems:
                        "center", justifyContent: 'center'
                },
                android: {
                    backgroundColor: 'green', margin: 20, height: 30, alignItems:
                        "center", justifyContent: 'center'
                },
            }),
        },
    });


